@@ -42,16 +42,16 @@ def get_itm(tms):
     Using this as a fixture with capsys breaks capsys. So we use a function.
     """
     itm = tm.InteractiveTomcatManager()
-    args = 'connect {url} {user} {password}'.format(**tms)
-    itm.onecmd_plus_hooks(args)
+    itm.onecmd_plus_hooks(tms.connect_command)
     return itm
 
+
 def itm_with_config(mocker, configstring):
     """Return an InteractiveTomcatManager object with the config set from the passed string."""
     itm = tm.InteractiveTomcatManager()
-    fd, fname = tempfile.mkstemp(prefix='', suffix='.ini')
+    fd, fname = tempfile.mkstemp(prefix="", suffix=".ini")
     os.close(fd)
-    with open(fname, 'w') as fobj:
+    with open(fname, "w") as fobj:
         fobj.write(configstring)
 
     # itm aleady tried to load a config file, which it may or may not
@@ -59,8 +59,10 @@ def itm_with_config(mocker, configstring):
     # we are now going to patch up the config_file to point to
     # a known file, and the reload the config from that
     try:
-        config_file = mocker.patch('tomcatmanager.InteractiveTomcatManager.config_file',
-                                   new_callable=mock.PropertyMock)
+        config_file = mocker.patch(
+            "tomcatmanager.InteractiveTomcatManager.config_file",
+            new_callable=mock.PropertyMock,
+        )
         config_file.return_value = fname
         itm.load_config()
         # this just verifies that our patch worked
@@ -69,96 +71,104 @@ def itm_with_config(mocker, configstring):
         os.remove(fname)
     return itm
 
+
 def assert_connected_to(itm, url, capsys):
-    itm.onecmd_plus_hooks('which')
+    itm.onecmd_plus_hooks("which")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
     assert url in out
 
+
 @pytest.fixture
 def itm_nc(mocker):
     """Don't allow it to load a config file"""
-    mocker.patch('tomcatmanager.InteractiveTomcatManager.load_config')
+    mocker.patch("tomcatmanager.InteractiveTomcatManager.load_config", autospec=True)
     itm = tm.InteractiveTomcatManager()
     return itm
 
+
 ###
 #
 # test help
 #
 ###
 HELP_COMMANDS = [
-    'config',
-    'show',
-    'settings',
-    'connect',
-    'which',
-    'deploy',
-    'redeploy',
-    'undeploy',
-    'start',
-    'stop',
-    'reload',
-    'restart',
-    'sessions',
-    'expire',
-    'list',
-    'serverinfo',
-    'status',
-    'vminfo',
-    'sslconnectorciphers',
-    'threaddump',
-    'resources',
-    'findleakers',
-    'version',
-    'license',
+    "config",
+    "show",
+    "settings",
+    "connect",
+    "which",
+    "deploy",
+    "redeploy",
+    "undeploy",
+    "start",
+    "stop",
+    "reload",
+    "restart",
+    "sessions",
+    "expire",
+    "list",
+    "serverinfo",
+    "status",
+    "vminfo",
+    "sslconnectorciphers",
+    "threaddump",
+    "resources",
+    "findleakers",
+    "version",
+    "license",
 ]
 # exit_code omitted because it doesn't respond
 # to -h or --help
-@pytest.mark.parametrize('command', HELP_COMMANDS)
+@pytest.mark.parametrize("command", HELP_COMMANDS)
 def test_command_help(tomcat_manager_server, command):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('{} -h'.format(command))
-    assert itm.exit_code == itm.exit_codes.usage
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("{} -h".format(command))
+    assert itm.exit_code == itm.EXIT_USAGE
+
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("{} --help".format(command))
+    assert itm.exit_code == itm.EXIT_USAGE
 
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('{} --help'.format(command))
-    assert itm.exit_code == itm.exit_codes.usage
 
 # copy the list
 HELP_ARGPARSERS = list(HELP_COMMANDS)
 # there is an argparser for exit_code, but it's only used
 # to generate the help
-HELP_ARGPARSERS.append('exit_code')
-@pytest.mark.parametrize('command', HELP_ARGPARSERS)
+HELP_ARGPARSERS.append("exit_code")
+
+
+@pytest.mark.parametrize("command", HELP_ARGPARSERS)
 def test_help_matches_argparser(command, capsys):
     itm = tm.InteractiveTomcatManager()
-    cmdline = 'help {}'.format(command)
+    cmdline = "help {}".format(command)
     itm.onecmd_plus_hooks(cmdline)
     out, _ = capsys.readouterr()
-    parser_func = getattr(itm, '{}_parser'.format(command))
+    parser_func = getattr(itm, "{}_parser".format(command))
     assert out == parser_func.format_help()
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 def test_help_set(capsys):
     itm = tm.InteractiveTomcatManager()
-    cmdline = 'help set'
+    cmdline = "help set"
     itm.onecmd_plus_hooks(cmdline)
     out, _ = capsys.readouterr()
-    assert 'change the value of one of this program\'s settings' in out
-    assert itm.exit_code == itm.exit_codes.success
+    assert "change the value of one of this program's settings" in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 def test_help(capsys):
     itm = tm.InteractiveTomcatManager()
-    cmdline = 'help'
+    cmdline = "help"
     itm.onecmd_plus_hooks(cmdline)
     out, _ = capsys.readouterr()
-    assert 'Connecting to a Tomcat server' in out
-    assert 'Managing applications' in out
-    assert 'Server information' in out
-    assert 'Settings, configuration, and tools' in out
-    assert itm.exit_code == itm.exit_codes.success
+    assert "Connecting to a Tomcat server" in out
+    assert "Managing applications" in out
+    assert "Server information" in out
+    assert "Settings, configuration, and tools" in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
 
 
 ###
@@ -167,68 +177,78 @@ def test_help(capsys):
 #
 ###
 BOOLEANS = [
-    ('1', True),
-    ('0', False),
-    ('y', True),
-    ('Y', True),
-    ('yes', True),
-    ('Yes', True),
-    ('YES', True),
-    ('n', False),
-    ('N', False),
-    ('no', False),
-    ('No', False),
-    ('NO', False),
-    ('on', True),
-    ('On', True),
-    ('ON', True),
-    ('off', False),
-    ('Off', False),
-    ('OFF', False),
-    ('t', True),
-    ('true', True),
-    ('True', True),
-    ('TRUE', True),
-    ('f', False),
-    ('false', False),
-    ('False', False),
-    ('FALSE', False),
+    ("1", True),
+    ("0", False),
+    ("y", True),
+    ("Y", True),
+    ("yes", True),
+    ("Yes", True),
+    ("YES", True),
+    ("n", False),
+    ("N", False),
+    ("no", False),
+    ("No", False),
+    ("NO", False),
+    ("on", True),
+    ("On", True),
+    ("ON", True),
+    ("off", False),
+    ("Off", False),
+    ("OFF", False),
+    ("t", True),
+    ("true", True),
+    ("True", True),
+    ("TRUE", True),
+    ("f", False),
+    ("false", False),
+    ("False", False),
+    ("FALSE", False),
     (True, True),
     (False, False),
 ]
-@pytest.mark.parametrize('param, value', BOOLEANS)
+
+
+@pytest.mark.parametrize("param, value", BOOLEANS)
 def test_convert_to_boolean_valid(param, value):
     itm = tm.InteractiveTomcatManager()
     assert itm.convert_to_boolean(param) == value
 
+
 NOT_BOOLEANS = [
     None,
-    '',
+    "",
     10,
-    'ace',
+    "ace",
 ]
-@pytest.mark.parametrize('param', NOT_BOOLEANS)
+
+
+@pytest.mark.parametrize("param", NOT_BOOLEANS)
 def test_convert_to_boolean_invalid(param):
     itm = tm.InteractiveTomcatManager()
     with pytest.raises(ValueError):
         itm.convert_to_boolean(param)
 
+
 LITERALS = [
-    ('fred', 'fred'),
-    ('fred ', "'fred '"),
+    ("fred", "fred"),
+    ("fred ", "'fred '"),
     ("can't ", '"can\'t "'),
-    ('b"d', '\'b"d\''),
-    ('b\'|"d', "\'b\\'|\"d'"),
+    ('b"d', "'b\"d'"),
+    ("b'|\"d", "'b\\'|\"d'"),
 ]
-@pytest.mark.parametrize('param, value', LITERALS)
+
+
+@pytest.mark.parametrize("param, value", LITERALS)
 def test_pythonize(param, value):
     itm = tm.InteractiveTomcatManager()
     assert itm._pythonize(param) == value
 
+
 def test_appdirs():
     itm = tm.InteractiveTomcatManager()
     assert itm.appdirs
 
+
 def test_config_file_property():
     itm = tm.InteractiveTomcatManager()
     # don't care where it is, just care that there is one
@@ -237,6 +257,7 @@ def test_config_file_property():
     itm.appdirs = None
     assert not itm.config_file
 
+
 def test_history_file_property():
     itm = tm.InteractiveTomcatManager()
     # don't care where it is, just care that there is one
@@ -245,52 +266,61 @@ def test_history_file_property():
     itm.appdirs = None
     assert not itm.history_file
 
+
 def test_config_edit(itm_nc, mocker):
-    itm_nc.editor = 'fooedit'
-    mock_os_system = mocker.patch('os.system')
-    itm_nc.onecmd_plus_hooks('config edit')
+    itm_nc.editor = "fooedit"
+    mock_os_system = mocker.patch("os.system")
+    itm_nc.onecmd_plus_hooks("config edit")
     assert mock_os_system.call_count == 1
-    assert itm_nc.exit_code == itm_nc.exit_codes.success
+    assert itm_nc.exit_code == itm_nc.EXIT_SUCCESS
+
 
 def test_config_edit_no_editor(itm_nc, capsys):
     itm_nc.editor = None
-    itm_nc.onecmd_plus_hooks('config edit')
+    itm_nc.onecmd_plus_hooks("config edit")
     out, err = capsys.readouterr()
-    assert itm_nc.exit_code == itm_nc.exit_codes.error
+    assert itm_nc.exit_code == itm_nc.EXIT_ERROR
     assert not out
-    assert err.startswith('no editor: ')
+    assert err.startswith("no editor: ")
+
 
 def test_config_invalid_action(itm_nc, capsys):
-    itm_nc.onecmd_plus_hooks('config bogus')
+    itm_nc.onecmd_plus_hooks("config bogus")
     out, err = capsys.readouterr()
-    assert itm_nc.exit_code == itm_nc.exit_codes.usage
+    assert itm_nc.exit_code == itm_nc.EXIT_USAGE
     assert not out
-    assert err.startswith('usage: ')
+    assert err.startswith("usage: ")
+
 
 def test_config_file_command(mocker, capsys):
-    fname = '/tmp/someconfig.ini'
+    fname = "/tmp/someconfig.ini"
     itm = tm.InteractiveTomcatManager()
 
-    config_file = mocker.patch('tomcatmanager.InteractiveTomcatManager.config_file',
-                               new_callable=mock.PropertyMock)
+    config_file = mocker.patch(
+        "tomcatmanager.InteractiveTomcatManager.config_file",
+        new_callable=mock.PropertyMock,
+    )
     config_file.return_value = fname
 
-    itm.onecmd_plus_hooks('config file')
+    itm.onecmd_plus_hooks("config file")
     out, _ = capsys.readouterr()
-    assert out == '{}\n'.format(fname)
-    assert itm.exit_code == itm.exit_codes.success
+    assert out == "{}\n".format(fname)
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 def test_load_config(mocker):
     prompt = str(uuid.uuid1())
-    configstring = '[settings]\nprompt={}\n'.format(prompt)
+    configstring = "[settings]\nprompt={}\n".format(prompt)
     itm = itm_with_config(mocker, configstring)
     assert itm.prompt == prompt
 
+
 def test_load_config_bogus_setting(mocker):
-    configstring = '[settings]\nbogus=True\n'
+    configstring = "[settings]\nbogus=True\n"
     # this shouldn't throw any exceptions
     itm_with_config(mocker, configstring)
 
+
 def test_load_config_not_boolean(itm_nc, mocker):
     configstring = '[settings]\necho="not a boolean"\n'
     # this shouldn't throw any exceptions
@@ -299,16 +329,20 @@ def test_load_config_not_boolean(itm_nc, mocker):
     # as when we don't load a config file
     assert itm_nc.echo == itm.echo
 
+
 def test_load_config_not_integer(itm_nc, mocker):
-    configstring = '[settings]\ntimeout=noganinteger\n'
+    configstring = "[settings]\ntimeout=noganinteger\n"
     # this shouldn't throw any exceptions
     itm = itm_with_config(mocker, configstring)
     # make sure the timeout setting is the same
     # as when we don't load a config file
     assert itm_nc.timeout == itm.timeout
 
-SHOW_SETTINGS = ['settings', 'show']
-@pytest.mark.parametrize('command', SHOW_SETTINGS)
+
+SHOW_SETTINGS = ["settings", "show"]
+
+
+@pytest.mark.parametrize("command", SHOW_SETTINGS)
 def test_show_noargs(command, capsys):
     itm = tm.InteractiveTomcatManager()
     itm.onecmd_plus_hooks(command)
@@ -316,67 +350,76 @@ def test_show_noargs(command, capsys):
     # not going to parse all the lines, but there
     # should be one per setting
     assert len(out.splitlines()) == len(itm.settables)
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
 
-@pytest.mark.parametrize('command', SHOW_SETTINGS)
+
+@pytest.mark.parametrize("command", SHOW_SETTINGS)
 def test_show_valid_setting(command, capsys):
     itm = tm.InteractiveTomcatManager()
-    itm.onecmd_plus_hooks('{} prompt'.format(command))
+    itm.onecmd_plus_hooks("{} prompt".format(command))
     out, _ = capsys.readouterr()
     assert out.startswith("prompt='{}' ".format(itm.prompt))
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
 
-@pytest.mark.parametrize('command', SHOW_SETTINGS)
+
+@pytest.mark.parametrize("command", SHOW_SETTINGS)
 def test_show_invalid_setting(command, capsys):
     itm = tm.InteractiveTomcatManager()
-    itm.onecmd_plus_hooks('{} bogus'.format(command))
+    itm.onecmd_plus_hooks("{} bogus".format(command))
     out, err = capsys.readouterr()
     assert not out
     assert err == "unknown setting: 'bogus'\n"
-    assert itm.exit_code == itm.exit_codes.error
+    assert itm.exit_code == itm.EXIT_ERROR
+
 
 def test_set_noargs(capsys):
     itm = tm.InteractiveTomcatManager()
-    itm.onecmd_plus_hooks('set')
+    itm.onecmd_plus_hooks("set")
     out, err = capsys.readouterr()
     assert not out
-    assert err == 'invalid syntax: try {setting}={value}\n'
-    assert itm.exit_code == itm.exit_codes.usage
+    assert err == "invalid syntax: try {setting}={value}\n"
+    assert itm.exit_code == itm.EXIT_USAGE
+
 
 def test_set_string():
     itm = tm.InteractiveTomcatManager()
     prompt = str(uuid.uuid1())
-    itm.onecmd_plus_hooks('set prompt={}'.format(prompt))
+    itm.onecmd_plus_hooks("set prompt={}".format(prompt))
     assert itm.prompt == prompt
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 def test_set_integer_valid():
     itm = tm.InteractiveTomcatManager()
     itm.timeout = 10
-    itm.onecmd_plus_hooks('set timeout=5')
+    itm.onecmd_plus_hooks("set timeout=5")
     assert itm.timeout == 5
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 def test_set_integer_invalid():
     itm = tm.InteractiveTomcatManager()
     itm.timeout = 10
-    itm.onecmd_plus_hooks('set timeout=joe')
+    itm.onecmd_plus_hooks("set timeout=joe")
     assert itm.timeout == 10
-    assert itm.exit_code == itm.exit_codes.error
+    assert itm.exit_code == itm.EXIT_ERROR
+
 
 def test_set_boolean_valid():
     itm = tm.InteractiveTomcatManager()
     itm.echo = False
-    itm.onecmd_plus_hooks('set echo=True')
+    itm.onecmd_plus_hooks("set echo=True")
     assert itm.echo is True
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 def test_set_boolean_invalid():
     itm = tm.InteractiveTomcatManager()
     itm.echo = False
-    itm.onecmd_plus_hooks('set echo=notaboolean')
+    itm.onecmd_plus_hooks("set echo=notaboolean")
     assert itm.echo is False
-    assert itm.exit_code == itm.exit_codes.error
+    assert itm.exit_code == itm.EXIT_ERROR
+
 
 def test_set_with_invalid_param():
     itm = tm.InteractiveTomcatManager()
@@ -384,62 +427,72 @@ def test_set_with_invalid_param():
     invalid_setting = str(uuid.uuid1())
     with pytest.raises(ValueError):
         # pylint: disable=protected-access
-        itm._change_setting(invalid_setting, 'someval')
+        itm._change_setting(invalid_setting, "someval")
+
 
 def test_timeout_property():
-    timeout = 10
+    timeout = 8.5
     itm = tm.InteractiveTomcatManager()
     # set this to a value that we know will cause it to change when we execute
     # the command
     itm.timeout = 5
     assert itm.tomcat.timeout == 5
-    itm.onecmd_plus_hooks('set timeout={}'.format(timeout))
-    assert itm.exit_code == itm.exit_codes.success
+    itm.onecmd_plus_hooks("set timeout={}".format(timeout))
+    assert itm.exit_code == itm.EXIT_SUCCESS
     assert itm.timeout == timeout
     assert itm.tomcat.timeout == timeout
 
+
 SETTINGS_SUCCESSFUL = [
-    ('prompt=tm>', 'tm>'),
-    ('prompt=tm> ', 'tm>'),
-    ('prompt=t m>', 't m>'),
-    ('prompt="tm> "', 'tm> '),
-    ('prompt="tm> "   # some comment here', 'tm> '),
-    ('prompt="t\'m> "', "t\'m> "),
+    ("prompt=tm>", "tm>"),
+    ("prompt=tm> ", "tm>"),
+    ("prompt=t m>", "t m>"),
+    ('prompt="tm> "', "tm> "),
+    ('prompt="tm> "   # some comment here', "tm> "),
+    ('prompt="t\'m> "', "t'm> "),
     ('prompt="""h\'i"""', "h'i"),
 ]
-@pytest.mark.parametrize('arg, value', SETTINGS_SUCCESSFUL)
+
+
+@pytest.mark.parametrize("arg, value", SETTINGS_SUCCESSFUL)
 def test_do_set_success(arg, value):
     itm = tm.InteractiveTomcatManager()
     itm.do_set(arg)
     assert itm.prompt == value
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 SETTINGS_FAILURE = [
-    'thisisntaparam=somevalue',
-    'thisisntaparam',
+    "thisisntaparam=somevalue",
+    "thisisntaparam",
 ]
-@pytest.mark.parametrize('arg', SETTINGS_FAILURE)
+
+
+@pytest.mark.parametrize("arg", SETTINGS_FAILURE)
 def test_do_set_fail(arg):
     itm = tm.InteractiveTomcatManager()
     itm.do_set(arg)
-    assert itm.exit_code == itm.exit_codes.error
+    assert itm.exit_code == itm.EXIT_ERROR
+
 
 PREFIXES = [
-    ('--', '--'),
-    ('*', '*'),
-    ('>>>', '>>>'),
+    ("--", "--"),
+    ("*", "*"),
+    (">>>", ">>>"),
     # with no prefix, we should see the connected message
-    ('', 'connected'),
+    ("", "connected"),
 ]
-@pytest.mark.parametrize('prefix, expected', PREFIXES)
+
+
+@pytest.mark.parametrize("prefix, expected", PREFIXES)
 def test_status_prefix(tomcat_manager_server, prefix, expected, capsys):
     itm = tm.InteractiveTomcatManager()
-    args = 'connect {url} {user} {password}'.format(**tomcat_manager_server)
     itm.status_prefix = prefix
-    itm.onecmd_plus_hooks(args)
+    itm.onecmd_plus_hooks(tomcat_manager_server.connect_command)
     out, err = capsys.readouterr()
     assert err.startswith(expected)
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 ###
 #
@@ -448,112 +501,129 @@ def test_status_prefix(tomcat_manager_server, prefix, expected, capsys):
 ###
 def test_connect(tomcat_manager_server, capsys):
     itm = tm.InteractiveTomcatManager()
-    cmdline = 'connect {url} {user} {password}'.format(**tomcat_manager_server)
-    itm.onecmd_plus_hooks(cmdline)
-    assert itm.exit_code == itm.exit_codes.success
-    assert_connected_to(itm, tomcat_manager_server['url'], capsys)
+    itm.onecmd_plus_hooks(tomcat_manager_server.connect_command)
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert_connected_to(itm, tomcat_manager_server.url, capsys)
+
 
 def test_connect_password_prompt(tomcat_manager_server, capsys, mocker):
     itm = tm.InteractiveTomcatManager()
-    mock_getpass = mocker.patch('getpass.getpass')
-    mock_getpass.return_value = tomcat_manager_server['password']
+    mock_getpass = mocker.patch("getpass.getpass")
+    mock_getpass.return_value = tomcat_manager_server.password
     # this should call getpass.getpass, which is now mocked to return the password
-    cmdline = 'connect {url} {user}'.format(**tomcat_manager_server)
+    cmdline = "connect {} {}".format(
+        tomcat_manager_server.url, tomcat_manager_server.user
+    )
     itm.onecmd_plus_hooks(cmdline)
     # make sure it got called
     assert mock_getpass.call_count == 1
-    assert itm.exit_code == itm.exit_codes.success
-    assert_connected_to(itm, tomcat_manager_server['url'], capsys)
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert_connected_to(itm, tomcat_manager_server.url, capsys)
+
 
 def test_connect_config(tomcat_manager_server, capsys, mocker):
     configname = str(uuid.uuid1())
     config = """[{}]
-    url={url}
-    user={user}
-    password={password}"""
-    configstring = config.format(configname, **tomcat_manager_server)
+    url={}
+    user={}
+    password={}"""
+    configstring = config.format(
+        configname,
+        tomcat_manager_server.url,
+        tomcat_manager_server.user,
+        tomcat_manager_server.password,
+    )
     itm = itm_with_config(mocker, configstring)
-    cmdline = 'connect {}'.format(configname)
+    cmdline = "connect {}".format(configname)
     itm.onecmd_plus_hooks(cmdline)
-    assert itm.exit_code == itm.exit_codes.success
-    assert_connected_to(itm, tomcat_manager_server['url'], capsys)
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert_connected_to(itm, tomcat_manager_server.url, capsys)
+
 
 def test_connect_config_password_prompt(tomcat_manager_server, capsys, mocker):
     configname = str(uuid.uuid1())
     config = """[{}]
-    url={url}
-    user={user}"""
-    configstring = config.format(configname, **tomcat_manager_server)
+    url={}
+    user={}"""
+    configstring = config.format(
+        configname, tomcat_manager_server.url, tomcat_manager_server.user
+    )
     itm = itm_with_config(mocker, configstring)
-    mock_getpass = mocker.patch('getpass.getpass')
-    mock_getpass.return_value = tomcat_manager_server['password']
+    mock_getpass = mocker.patch("getpass.getpass")
+    mock_getpass.return_value = tomcat_manager_server.password
     # this will call getpass.getpass, which is now mocked to return the password
-    cmdline = 'connect {}'.format(configname)
+    cmdline = "connect {}".format(configname)
     itm.onecmd_plus_hooks(cmdline)
     assert mock_getpass.call_count == 1
-    assert itm.exit_code == itm.exit_codes.success
-    assert_connected_to(itm, tomcat_manager_server['url'], capsys)
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert_connected_to(itm, tomcat_manager_server.url, capsys)
+
 
 def test_connect_with_connection_error(tomcat_manager_server, capsys, mocker):
-    connect_mock = mocker.patch('tomcatmanager.TomcatManager.connect')
+    connect_mock = mocker.patch("tomcatmanager.TomcatManager.connect")
     connect_mock.side_effect = requests.exceptions.ConnectionError()
     itm = tm.InteractiveTomcatManager()
-    cmdline = 'connect {url} {user} {password}'.format(**tomcat_manager_server)
-    itm.onecmd_plus_hooks(cmdline)
+    itm.debug = False
+    itm.onecmd_plus_hooks(tomcat_manager_server.connect_command)
     out, err = capsys.readouterr()
     assert not out
     assert connect_mock.call_count == 1
-    assert err == 'connection error\n'
-    assert itm.exit_code == itm.exit_codes.error
+    assert err == "connection error\n"
+    assert itm.exit_code == itm.EXIT_ERROR
+
 
 def test_connect_with_timeout(tomcat_manager_server, capsys, mocker):
-    connect_mock = mocker.patch('tomcatmanager.TomcatManager.connect')
+    connect_mock = mocker.patch("tomcatmanager.TomcatManager.connect")
     connect_mock.side_effect = requests.exceptions.Timeout()
     itm = tm.InteractiveTomcatManager()
-    cmdline = 'connect {url} {user} {password}'.format(**tomcat_manager_server)
-    itm.onecmd_plus_hooks(cmdline)
+    itm.debug = False
+    itm.onecmd_plus_hooks(tomcat_manager_server.connect_command)
     out, err = capsys.readouterr()
     assert not out
     assert connect_mock.call_count == 1
-    assert err == 'connection timeout\n'
-    assert itm.exit_code == itm.exit_codes.error
+    assert err == "connection timeout\n"
+    assert itm.exit_code == itm.EXIT_ERROR
+
 
 def test_which(tomcat_manager_server, capsys):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('which')
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("which")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
-    assert tomcat_manager_server['url'] in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert tomcat_manager_server.url in out
+
 
 REQUIRES_CONNECTION = [
-    'which',
-    'deploy',
-    'redeploy',
-    'undeploy',
-    'start',
-    'stop',
-    'reload',
-    'restart',
-    'sessions',
-    'expire',
-    'list',
-    'serverinfo',
-    'status',
-    'vminfo',
-    'sslconnectorciphers',
-    'threaddump',
-    'resources',
-    'findleakers',
+    "which",
+    "deploy",
+    "redeploy",
+    "undeploy",
+    "start",
+    "stop",
+    "reload",
+    "restart",
+    "sessions",
+    "expire",
+    "list",
+    "serverinfo",
+    "status",
+    "vminfo",
+    "sslconnectorciphers",
+    "threaddump",
+    "resources",
+    "findleakers",
 ]
-@pytest.mark.parametrize('command', REQUIRES_CONNECTION)
+
+
+@pytest.mark.parametrize("command", REQUIRES_CONNECTION)
 def test_requires_connection(command, capsys):
     itm = tm.InteractiveTomcatManager()
     itm.onecmd_plus_hooks(command)
     out, err = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.error
+    assert itm.exit_code == itm.EXIT_ERROR
     assert not out
-    assert err == 'not connected\n'
+    assert err == "not connected\n"
 
 
 ###
@@ -562,88 +632,128 @@ def test_requires_connection(command, capsys):
 #
 ###
 NOARGS_INFO_COMMANDS = [
-    'serverinfo',
-    'status',
-    'vminfo',
-    'sslconnectorciphers',
-    'threaddump',
-    'findleakers',
+    "serverinfo",
+    "status",
+    "vminfo",
+    "sslconnectorciphers",
+    "threaddump",
+    "findleakers",
 ]
-@pytest.mark.parametrize('cmdname', NOARGS_INFO_COMMANDS)
+
+
+@pytest.mark.parametrize("cmdname", NOARGS_INFO_COMMANDS)
 def test_info_commands_noargs(tomcat_manager_server, cmdname):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.success
-    itm.onecmd_plus_hooks('{} argument'.format(cmdname))
-    assert itm.exit_code == itm.exit_codes.usage
+    itm.exit_code = itm.EXIT_SUCCESS
+    itm.onecmd_plus_hooks("{} argument".format(cmdname))
+    assert itm.exit_code == itm.EXIT_USAGE
+
 
 def test_serverinfo(tomcat_manager_server, capsys):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('serverinfo')
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("serverinfo")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
-    assert 'Tomcat Version: ' in out
-    assert 'JVM Version: ' in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert "Tomcat Version: " in out
+    assert "JVM Version: " in out
+
 
 def test_status(tomcat_manager_server, capsys):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('status')
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("status")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
-    assert '</status>' in out
-    assert '</jvm>' in out
-    assert '</connector>' in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert "</status>" in out
+    assert "</jvm>" in out
+    assert "</connector>" in out
+
 
 def test_vminfo(tomcat_manager_server, capsys):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('vminfo')
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("vminfo")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
-    assert 'Runtime information:' in out
-    assert 'architecture:' in out
-    assert 'System properties:' in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert "Runtime information:" in out
+    assert "architecture:" in out
+    assert "System properties:" in out
+
 
 def test_sslconnectorciphers(tomcat_manager_server, capsys):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('sslconnectorciphers')
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("sslconnectorciphers")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
-    assert 'Connector' in out
-    assert 'SSL' in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert "Connector" in out
+    assert "SSL" in out
+
+
+def test_sslconnectorcerts(tomcat_manager_server, capsys):
+    itm = get_itm(tomcat_manager_server)
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("sslconnectorcerts")
+    out, _ = capsys.readouterr()
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert "Connector" in out
+    assert "SSL" in out
+
+
+def test_sslconnectortrustedcerts(tomcat_manager_server, capsys):
+    itm = get_itm(tomcat_manager_server)
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("sslconnectortrustedcerts")
+    out, _ = capsys.readouterr()
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert "Connector" in out
+    assert "SSL" in out
+
+
+def test_sslreload(tomcat_manager_server, capsys):
+    itm = get_itm(tomcat_manager_server)
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("sslreload")
+    out, err = capsys.readouterr()
+    assert "load" in out or "load" in err
+    assert "TLS" in out or "TLS" in err
+
 
 def test_threaddump(tomcat_manager_server, capsys):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('threaddump')
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("threaddump")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
-    assert 'java.lang.Thread.State' in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert "java.lang.Thread.State" in out
+
 
 def test_resources(tomcat_manager_server, capsys):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('resources')
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("resources")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
-    assert 'UserDatabase: ' in out
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert "UserDatabase: " in out
+
 
 def test_resources_class_name(tomcat_manager_server, capsys):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.success
+    itm.exit_code = itm.EXIT_SUCCESS
     # this class has to be hand coded in the mock server
-    itm.onecmd_plus_hooks('resources com.example.Nothing')
+    itm.onecmd_plus_hooks("resources com.example.Nothing")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.error
+    assert itm.exit_code == itm.EXIT_ERROR
     assert not out
 
+
 def test_findleakers(tomcat_manager_server):
     itm = get_itm(tomcat_manager_server)
-    itm.exit_code = itm.exit_codes.error
-    itm.onecmd_plus_hooks('findleakers')
-    assert itm.exit_code == itm.exit_codes.success
+    itm.exit_code = itm.EXIT_ERROR
+    itm.onecmd_plus_hooks("findleakers")
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 ###
 #
@@ -652,42 +762,47 @@ def test_findleakers(tomcat_manager_server):
 ###
 def test_exit():
     itm = tm.InteractiveTomcatManager()
-    itm.onecmd_plus_hooks('exit')
-    assert itm.exit_code == itm.exit_codes.success
+    itm.onecmd_plus_hooks("exit")
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 def test_quit():
     itm = tm.InteractiveTomcatManager()
-    itm.onecmd_plus_hooks('quit')
-    assert itm.exit_code == itm.exit_codes.success
+    itm.onecmd_plus_hooks("quit")
+    assert itm.exit_code == itm.EXIT_SUCCESS
+
 
 def test_exit_code(capsys):
     itm = tm.InteractiveTomcatManager()
-    itm.onecmd_plus_hooks('version')
+    itm.onecmd_plus_hooks("version")
     out, _ = capsys.readouterr()
-    itm.onecmd_plus_hooks('exit_code')
+    itm.onecmd_plus_hooks("exit_code")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
-    assert out == '{}\n'.format(itm.exit_codes.success)
+    assert itm.exit_code == itm.EXIT_SUCCESS
+    assert out == "{}\n".format(itm.EXIT_SUCCESS)
+
 
 def test_version(capsys):
     itm = tm.InteractiveTomcatManager()
-    itm.onecmd_plus_hooks('version')
+    itm.onecmd_plus_hooks("version")
     out, _ = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.success
+    assert itm.exit_code == itm.EXIT_SUCCESS
     assert tm.__version__ in out
 
+
 def test_default(capsys):
-    cmdline = 'notacommand'
+    cmdline = "notacommand"
     itm = tm.InteractiveTomcatManager()
     itm.onecmd_plus_hooks(cmdline)
     out, err = capsys.readouterr()
-    assert itm.exit_code == itm.exit_codes.command_not_found
+    assert itm.exit_code == itm.EXIT_COMMAND_NOT_FOUND
     assert not out
-    assert err == 'unknown command: {}\n'.format(cmdline)
+    assert err == "unknown command: {}\n".format(cmdline)
+
 
 def test_license(capsys):
     itm = tm.InteractiveTomcatManager()
-    itm.onecmd_plus_hooks('license')
+    itm.onecmd_plus_hooks("license")
     out, _ = capsys.readouterr()
     expected = """
 Copyright 2007 Jared Crapo
